@@ -65,7 +65,7 @@ def init(args):
         #session_skeleton_sapofto = nwbfile_in.get_scratch('nwborglab_session_source_code')
         
         SAPOFTO.recursiveFolderWrite(sensors_sapofto, os.getcwd(), safe_mode=True)
-        overview.writeToFile(os.getcwd())
+        overview_sapofto.writeToFile(os.getcwd())
         session_skeleton_sapofto.writeToFile(os.getcwd())
         return
     
